# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V2APISubresourceDiscovery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'subresource': 'str',
        'response_kind': 'IoK8sApimachineryPkgApisMetaV1GroupVersionKind',
        'accepted_types': 'list[IoK8sApimachineryPkgApisMetaV1GroupVersionKind]',
        'verbs': 'list[str]'
    }

    attribute_map = {
        'subresource': 'subresource',
        'response_kind': 'responseKind',
        'accepted_types': 'acceptedTypes',
        'verbs': 'verbs'
    }

    def __init__(self, subresource=None, response_kind=None, accepted_types=None, verbs=None, local_vars_configuration=None):  # noqa: E501
        """V2APISubresourceDiscovery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._subresource = None
        self._response_kind = None
        self._accepted_types = None
        self._verbs = None
        self.discriminator = None

        self.subresource = subresource
        if response_kind is not None:
            self.response_kind = response_kind
        if accepted_types is not None:
            self.accepted_types = accepted_types
        self.verbs = verbs

    @property
    def subresource(self):
        """Gets the subresource of this V2APISubresourceDiscovery.  # noqa: E501

        subresource is the name of the subresource.  # noqa: E501

        :return: The subresource of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: str
        """
        return self._subresource

    @subresource.setter
    def subresource(self, subresource):
        """Sets the subresource of this V2APISubresourceDiscovery.

        subresource is the name of the subresource.  # noqa: E501

        :param subresource: The subresource of this V2APISubresourceDiscovery.  # noqa: E501
        :type subresource: str
        """
        if self.local_vars_configuration.client_side_validation and subresource is None:  # noqa: E501
            raise ValueError("Invalid value for `subresource`, must not be `None`")  # noqa: E501

        self._subresource = subresource

    @property
    def response_kind(self):
        """Gets the response_kind of this V2APISubresourceDiscovery.  # noqa: E501


        :return: The response_kind of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: IoK8sApimachineryPkgApisMetaV1GroupVersionKind
        """
        return self._response_kind

    @response_kind.setter
    def response_kind(self, response_kind):
        """Sets the response_kind of this V2APISubresourceDiscovery.


        :param response_kind: The response_kind of this V2APISubresourceDiscovery.  # noqa: E501
        :type response_kind: IoK8sApimachineryPkgApisMetaV1GroupVersionKind
        """

        self._response_kind = response_kind

    @property
    def accepted_types(self):
        """Gets the accepted_types of this V2APISubresourceDiscovery.  # noqa: E501


        :return: The accepted_types of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: list[IoK8sApimachineryPkgApisMetaV1GroupVersionKind]
        """
        return self._accepted_types

    @accepted_types.setter
    def accepted_types(self, accepted_types):
        """Sets the accepted_types of this V2APISubresourceDiscovery.


        :param accepted_types: The accepted_types of this V2APISubresourceDiscovery.  # noqa: E501
        :type accepted_types: list[IoK8sApimachineryPkgApisMetaV1GroupVersionKind]
        """

        self._accepted_types = accepted_types

    @property
    def verbs(self):
        """Gets the verbs of this V2APISubresourceDiscovery.  # noqa: E501

        verbs is a list of supported API operation types  # noqa: E501

        :return: The verbs of this V2APISubresourceDiscovery.  # noqa: E501
        :rtype: list[str]
        """
        return self._verbs

    @verbs.setter
    def verbs(self, verbs):
        """Sets the verbs of this V2APISubresourceDiscovery.

        verbs is a list of supported API operation types  # noqa: E501

        :param verbs: The verbs of this V2APISubresourceDiscovery.  # noqa: E501
        :type verbs: list[str]
        """
        if self.local_vars_configuration.client_side_validation and verbs is None:  # noqa: E501
            raise ValueError("Invalid value for `verbs`, must not be `None`")  # noqa: E501

        self._verbs = verbs

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V2APISubresourceDiscovery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V2APISubresourceDiscovery):
            return True

        return self.to_dict() != other.to_dict()
